@@ -46,19 +46,19 @@ class Idiot: public DealerScene
 
 public:
     explicit Idiot( const DealerInfo * di );
-    virtual void initialize();
-    virtual bool isGameWon() const;
+    void initialize() override;
+    bool isGameWon() const override;
 
 protected:
-    virtual void setGameState( const QString & state );
-    virtual bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const;
-    virtual bool checkRemove(const PatPile * pile, const QList<KCard*> & cards) const;
-    virtual void restart( const QList<KCard*> & cards );
-    virtual bool drop();
+    void setGameState( const QString & state ) override;
+    bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const override;
+    bool checkRemove(const PatPile * pile, const QList<KCard*> & cards) const override;
+    void restart( const QList<KCard*> & cards ) override;
+    bool drop() override;
 
 protected slots:
-    virtual bool newCards();
-    virtual bool tryAutomaticMove( KCard * card );
+    bool newCards() override;
+    bool tryAutomaticMove( KCard * card ) override;
 
 private:
     void dealRow();
