@@ -183,7 +183,7 @@ public:
       : DealerInfo(I18N_NOOP("Simple Simon"), SimpleSimonId)
     {}
 
-    DealerScene *createGame() const Q_DECL_OVERRIDE
+    DealerScene *createGame() const override
     {
         return new Simon( this );
     }
